/**
 * Este modulo es el encargado de mantener la programacion de las tareas que se deben ejecutar en twitbin
 **/

var TaskScheduler = function(){
	this.tasks = [];
	this.defaultTime = '1';//1 minuto por defecto
	this.fractionTime = '60000';//fraccion cada 1 minuto
	this.task = null;
	this.stop = false;
	this.inEjecution = false;
	this.taskToRemove = null;
	this.taskToAdd = null;
	this.taskToAddTime = null;
	this.newRateTime = null;
	this.MinPercent = 22;//porcentaje de pedidos restantes sobre el total en el cual se comenzara a chequear el scheduler.
	this.plus = 0;
}

TaskScheduler.prototype = {

	/**
		*Este metodo agrega la funcion indicada en el arreglo de funciones para que la misma sea ejecutada en adelante segun el time indicado.
		*Ademas la ejecuta inmediatamente.
	*/
	add: function  add (task,time,fixedTime){
		var newTask, auxTime;

		//no agregar duplicados
		if(this.exist(task)){ return false; }

		//si esta en ejecucion ??? y salir
		if(this.inEjecution){ 
			this.taskToAdd = task;
			this.taskToAddTime = time;
			return true;
		}

		// fix fixedTimr param
		if((typeof(fixedTime)=="undefined")||(!fixedTime)){
			fixedTime = "false";
		}else{
			fixedTime = "true";
		}

		//
		// add new task depending on time parameter
		//

		//es un valor incorrecto
		//es un string con los valores cero/default/null
		if ( (isNaN(time) && isNaN(parseInt(time)) ) || (isNaN(time) && ((time == '0') || (time == 'default') || (time == null)) ) ){
			newTask = [{"task":task,"time":twitbin.taskScheduler.defaultTime,"count":'0',"fixedTime":fixedTime}];
			twitbin.debug.showMessage("Se llamo a la funcion taskScheduler.add con time = "+time);
		}

		//es un string con una representacion numerica > 0
		else if (isNaN(time) && !isNaN( parseInt(time) ) ){
			newTask = [{"task":task,"time":time,"count":'0',"fixedTime":fixedTime}];
		}

		// es un numero valido
		else if (!isNaN(time)){
			auxTime = time.toString();
			if(auxTime == '0'){
				auxTime = twitbin.taskScheduler.defaultTime;
			}
			newTask = [{"task":task,"time":auxTime,"count":'0',"fixedTime":fixedTime}];
		}

		// no deberia pasar nunca
		else {
			newTask = [{"task":task,"time":twitbin.taskScheduler.defaultTime,"count":'0',"fixedTime":fixedTime}];
			twitbin.debug.showMessage("Se llamo a la funcion taskScheduler.add con time = "+time);
		}

		//se guarda y se ejecuta
		twitbin.taskScheduler.tasks = twitbin.taskScheduler.tasks.concat(newTask);
		twitbin.callback.execute(task);
	},

	setUniqueExecutionFunction: function setUniqueExecutionFunction(task,time_ms){
		setTimeout(function(){twitbin.callback.execute(task)},time_ms);
	},
	
	/**
		*Esta funcion recorre el arreglo de funciones cargadas y ejecuta aquellas funciones cuyos valores de time y count coinciden, e incrementa
		*el valor de count en aquellas funciones donde esto no sucede. Ademas al ejecutar una funcion setea a 0 el valor de count de la misma.
	*/
	execute: function execute(){
		var i,count;
	
		this.inEjecution = true;//se bloquea el arreglo de tareas

		for(i=0;i<twitbin.taskScheduler.tasks.length;i++){
			count = parseInt(twitbin.taskScheduler.tasks[i].count) + 1;
			twitbin.taskScheduler.tasks[i].count = count.toString();
			if(twitbin.taskScheduler.tasks[i].time <= twitbin.taskScheduler.tasks[i].count){
				//Se utiliza setTimeout para poder seguir la ejecucion concurrente, si esto no fuera asi
				//el sistema deberia esperar que termine la ejecucion de una funcion para poder ejecutar otra
				twitbin.callback.execute(twitbin.taskScheduler.tasks[i].task);
				twitbin.taskScheduler.tasks[i].count = '0';
			}
		}

		this.inEjecution = false;//se desbloquea el arreglo de tareas para poder ser borrado.

		this.checkRateLimit();

		if(!this.stop){
			if(this.taskToRemove != null){//caso en el que se pidio eliminar una tarea mientras se ejecutaba el cron
				this.remove(this.taskToRemove);
				this.taskToRemove = null;
			}
			if(this.taskToAdd != null){//caso en el que se pidio agregar una tarea mientras se ejecutaba el cron
				this.add(this.taskToAdd,this.toAddTime);
				this.taskToAdd = null;
				this.toAddTime = null;
			}
			if(this.newRateTime !=null){
				this.setRateTime(this.newRateTime);
				this.newRateTime = null;
			}
			this.task = setTimeout(function(){twitbin.taskScheduler.execute()},twitbin.taskScheduler.fractionTime);
		}
	},

	/**
		*Este metodo comienza la exejucion del modulo.
	*/
	init: function init(){
		this.stop = false;
		this.tasks = [];//se borran las tareas para volver a comenzar la ejecucion desde cero.
		this.task = setTimeout(function(){twitbin.taskScheduler.execute()},twitbin.taskScheduler.fractionTime);
	},

	/**
		*Este metodo elimina la funcion indicada del arreglo de funciones para que la misma no vuelva a ejecutarse en adelante.
	*/
	remove: function  remove (task){
		var pos = this.exist(task);

		if(!pos) { return false; }

		if(this.inEjecution){
			this.taskToRemove = task;
			return true;
		}

		twitbin.taskScheduler.tasks.splice(pos,1);
		return true;
	},

	/**
		*Este metodo si la tarea ya se encuentra cargada en el scheduler retorna true y false en caso contrario.
	*/
	exist: function exist(task){
		var i;

		for(i=0;i<twitbin.taskScheduler.tasks.length;i++){
			if(twitbin.debug.jsonToString(twitbin.taskScheduler.tasks[i].task) == twitbin.debug.jsonToString(task)){
				return i;
			}
		}
		return false;
	},

	/**
	 * para el scheduler
	 */
	finish: function finish(){

		if(this.inEjecution){
			this.stop = true;
			return true;
		}

		clearTimeout(this.task);
	},

	/**
	 *Cambia el tiempo de las tareas del scheduler. 
	 */
	setRateTime: function setRateTime(newTime){
		var count,time,newCount;

		//falta campo
		if((typeof(newTime)=="undefined")||(newTime == null)){ 
			twitbin.message.set('error','105',['newTime is not valid.','missing parameter \'newTime\' in function taskScheduler.setRateTime']);
			return false;
		}

		//si esta en ejecucion lo hago despues
		if(this.inEjecution){
			this.newRateTime = newtime; 
			return true;
		}

		for(i=0;i<twitbin.taskScheduler.tasks.length;i++){
			if(twitbin.taskScheduler.tasks[i].fixedTime != "false"){ continue; }

			count = parseInt(twitbin.taskScheduler.tasks[i].count);
			time = parseInt(twitbin.taskScheduler.tasks[i].time);

			if(isNaN(newTime)){
				twitbin.taskScheduler.tasks[i].time = newTime;//asigno el nuevo tiempo a la tarea.
				newTime = parseInt(newTime);//luego de asignarlo lo convierto en entero para hacer las comparaciones.
			}else{
				twitbin.taskScheduler.tasks[i].time = newTime.toString();//Convierto el tiempo a string y lo asigno  a la tarea.
			}

			//menor rate de refresco
			//si al sacarle tiempo entonces ya se deberia haber ejecutado, entonces hago que se ejecute en la proxima iteracion.
			if(time > newTime && count >= newTime){
				newCount = newTime -1;
				twitbin.taskScheduler.tasks[i].count = newCount.toString();
			}

		}
	},

	checkRateLimit: function checkRateLimit(){
		if(!twitbin.userLogged()){ return false; }

		twitbin.utils.callHandler({"f1":"getRateLimitStatus","p1":null,"f2":"twitbin.taskScheduler.delayScheduler","p2":null},'twitter');
	},

	delayScheduler: function delayScheduler(response){

		var percent, d, UTCdate, remaining_time, remainingMinutes, prefTime, plus, times,
		total = parseInt(response.hourly_limit),
		remaining = parseInt(response.remaining_hits);

		//si la cantidad de pedidos restantes es 0, ya no tiene nada que hacer.
		if(remaining == 0){ return true; }

		//calculo el porcentaje de llamadas restantes
		percent = this.roundNumber((remaining * 100) / total);

		//El porcentaje de pedidos restantes supera el porcentaje minimo establecido.
		//Por lo tanto deshabilito el plus y vuelvo todas las tareas a la normalidad.
		if(percent > this.MinPercent){
			if(this.plus != 0){
				var prefTime = twitbin.getPrefTimeRateOfUser();
				this.setRateTime(prefTime);
				this.plus = 0;
			}
			return true;
		}

		//obtengo la cantidad de minutos que faltan hasta el reset del tiempo en twitter
		d = new Date();
		UTCdate = d.toUTCString();
		remaining_time = Date.parse(response.reset_time) - Date.parse(UTCdate);
		remainingMinutes = this.roundNumber(remaining_time / 1000 / 60);

		//obtengo el rate seteado por el usuario.
		prefTime = twitbin.getPrefTimeRateOfUser();//preferencias del usuario.

		//obtengo el plus seteado hasta el momento
		plus = this.plus;

		//calculo la cantidad de veces que se ejecutaran las tareas
		times = this.roundNumber(remainingMinutes / (prefTime + plus));

		//calculo el nuevo plus
		while(((6 * times) > remaining) && (plus < 3)){
			plus++;
			times = this.roundNumber(remainingMinutes / (prefTime + plus));//calculo la cantidad de veces que se ejecutaran las tareas
		}

		//aplico el plus a todas las tareas no fijas, y seteo el plus del modulo para saber que hay un plus aplicado
		if(this.plus != plus){
			this.plus = plus;
			this.setRateTime(prefTime+plus);
		}
	},

	

	roundNumber: function roundNumber(number) {
		return Math.floor(parseFloat(number));
	},

	//Solo debe usarse para controlar las tareas que se estan ejecutando.
	seeTheTask: function seeTheTask(){
		var tareas = "";
		for(i=0;i<twitbin.taskScheduler.tasks.length;i++){
			tareas += ", "+twitbin.taskScheduler.tasks[i].task+" with time -->"+twitbin.taskScheduler.tasks[i].time;
		}
		alert(tareas);
	},

}
