/**
 * Este modulo realiza el control sobre la vista en cuanto a que tabs o datos se deben mostrar o ocultar.
 * Incluye el modulo viewInterface por el cual tambien se indica de que forma y con que estilos mostrar la informacion.
 **/
var ViewController = function(){
    this.viewInterface = new ViewInterface();
    /*
     * Indica que vista esta activa
     */
    this.viewCurrent = "";
    /*
     * Indica que accion se hara sobre la vista
     * 1: Mostrar listado
     * 2: Agregar mas elementos al final del listado
     * 3: Hay nuevos elementos para agregar al inicio del listado
     */
    this.viewAction = 0;
    /*
     * Id del ultimo elemento de la vista
     */
    this.viewFirstItem = 0;

    /*
     * Id del ultimo elemento obtenido por un sheduler pero en espera de ser
     * mostrado en la vista cuando se hace click en el mensaje de nuevos tweets
     */
    this.viewFirstItemTemp = 0;
    /*
     * Id de la lista que se esta visualizando
     */
    this.viewTweetsOfListCurrent = 0;
    /*
     * Id de la busqueda que se esta visualizando
     */
    this.viewTweetsOfSearchCurrent = 0;
    /*
     * Id del ultimo elemento de la vista
     */
    this.viewLastItem = 0;
    /*
     * Indica en el mensaje directo cual conversacion se esta viendo
     */
    this.viewScreenName = "";
    /*
     * Indica cuantos elementos se mostraran en la lista al entrar en una vista
     */
    this.viewQuantityItems = 10;
}

ViewController.prototype = {

//--------------------------------------------
//	 PUBLIC TWEETS
//--------------------------------------------

	//busca tweets para mostrar el tab de time line (solo en la pantalla de logueo)
	showPublicTweets: function showPublicTweets() {
		var result = twitbin.dbtwitbin.query(
			"SELECT *  FROM temp_tweets " +
			"WHERE type_tweet = 'Public' " +
			"ORDER BY tweet_id DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "Public";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showPublicTweets(result);
	},

//--------------------------------------------
//	 TIME LINE
//--------------------------------------------

	//busca tweets para mostrar el tab de time line
	showTimeLineTweets: function showTimeLineTweets() {
		//report
		twitbin.reports.add('Session.timeline');

		var result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND type_tweet = 'TimeLine' " +
			"ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "TimeLine";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showTimeLineTweets(result);
	},

	//busca tweets para apendar al final, al hacer scroll
	appendTimeLineTweets: function appendTimeLineTweets() {
		var result,
		created = $("#" + this.viewLastItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created < " + created + " AND type_tweet = 'TimeLine' " +
			"ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "TimeLine";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showTimeLineTweets(result);
	},

	//busca tweets para apendar como nuevos (escondidos)
	appendNewTimeLineTweets: function appendNewTimeLineTweets() {
		var result,
		created = $("#" + this.viewFirstItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created > " + created + " AND type_tweet = 'TimeLine' " +
			"ORDER BY created DESC "
		);
		this.viewCurrent = "TimeLine";
		this.viewAction = 3;
		this.viewInterface.showTimeLineTweets(result);
	},

//--------------------------------------------
//	 MENTIONS
//--------------------------------------------

	//busca tweets para mostrar el tab de mentions
	showMentionsTweets: function showMentionsTweets() {
		//report
		twitbin.reports.add('Session.mentions');

		var result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND type_tweet = 'Mentions' " +
			"ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "Mentions";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showMentionsTweets(result);
	},

	//busca tweets para apendar al final, al hacer scroll
	appendMentionsTweets: function appendMentionsTweets() {
		var result,
		created = $("#" + this.viewLastItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created < " + created + " AND type_tweet = 'Mentions' " +
			"ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "Mentions";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showMentionsTweets(result);
	},

	//busca tweets para apendar como nuevos (escondidos)
	appendNewMentionsTweets: function appendNewMentionsTweets() {
		var result,
		created = $("#" + this.viewFirstItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT *  FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created > " + created + " AND type_tweet = 'Mentions' " +
			"ORDER BY created DESC "
		);
		this.viewCurrent = "Mentions";
		this.viewAction = 3;
		this.viewInterface.showMentionsTweets(result);
	},

//--------------------------------------------
//	 FAVORITES
//--------------------------------------------

	//busca tweets para mostrar el tab de Favorite Tweets
	showFavoriteTweets: function showFavoriteTweets() {
		//report
		twitbin.reports.add('Session.favorites');

		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND favorited = 1 " +
			"GROUP BY tweet_id ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);

		this.viewCurrent = "Favorite";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showFavoriteTweets(result);
	},

	//busca tweets para apendar al final, al hacer scroll
	appendFavoriteTweets: function appendFavoriteTweets() {

		var result,
		created = $("#" + this.viewLastItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT * FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created < " + created + " AND favorited = 1 " +
			"ORDER BY created DESC " +
			"LIMIT " + this.viewQuantityItems
		);
		this.viewCurrent = "Favorite";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}
		this.viewInterface.showFavoriteTweets(result);
	},

	//busca tweets para apendar como nuevos (escondidos)
	appendNewFavoriteTweets: function appendNewFavoriteTweets() {

		var result,
		created = $("#" + this.viewFirstItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT * FROM tweets " +
			"WHERE " +
				"twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND created > " + created + " AND favorited = 1 " +
			"ORDER BY created DESC "
		);
		this.viewCurrent = "Favorite";
		this.viewAction = 3;
		this.viewInterface.showFavoriteTweets(result);
	},

//--------------------------------------------
//	 DM
//--------------------------------------------

	//busca tweets para mostrar el tab de DM (lista de conversaciones)
	showDirectMessages: function showDirectMessages()
	{
		//report
		twitbin.reports.add('Session.messages');

		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM " +
				"(SELECT *, sender_screen_name as conversation " +
				"FROM direct_messages " +
				"WHERE sender_screen_name != '" + twitbin.getLoggedUserName() + "' " +
				" AND twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"UNION " +

				"SELECT *, recipient_screen_name as conversation " +
				"FROM direct_messages " +
				"WHERE recipient_screen_name != '" + twitbin.getLoggedUserName() + "' " +
				" AND twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"ORDER BY created ASC ) " +

			"GROUP BY conversation " +
			"ORDER BY created DESC "
		);

		this.viewCurrent = "direct_messages";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].direct_message_id;
			this.viewLastItem = result[(result.length - 1)].direct_message_id;
		}
		this.viewInterface.showDirectMessages(result);
	},

	//busca tweets para apendar como nuevos (escondidos)
	appendNewDirectMessages: function appendNewDirectMessages() {
		var result = twitbin.dbtwitbin.query(
			"SELECT *  FROM direct_messages " +
			"WHERE twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND created > " + $("#" + this.viewFirstItem + " .tweetCreated").html() + " " +
			"ORDER BY created ASC "
		);

		this.viewCurrent = "direct_messages";
		this.viewAction = 3;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].direct_message_id;
		}
		this.viewInterface.showDirectMessages(result);
	},

	//busca tweets para mostrar el tab de DM (una conversaciones)
	showConversationDirectMessages: function showConversationDirectMessages(screen_name)
	{
		this.viewScreenName = screen_name;
		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM direct_messages " +
			"WHERE (sender_screen_name = '" + screen_name + "' " +
			"OR recipient_screen_name = '" + screen_name + "') " +
			" AND twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"ORDER BY created DESC "
		);

		this.viewCurrent = "direct_messages_conversation";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].direct_message_id;
			this.viewLastItem = result[(result.length - 1)].direct_message_id;
		}

		this.viewInterface.showConversationDirectMessages(result);
	},

	//busca tweets para apendar como nuevos (escondidos)
	appendNewConversationDirectMessages: function appendNewConversationDirectMessages(screen_name)
	{
		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM direct_messages " +
			"WHERE (sender_screen_name = '" + screen_name + "' " +
			"OR recipient_screen_name = '" + screen_name + "') " +
			" AND twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			" AND created > " + $("#" + this.viewFirstItem + " .tweetCreated").html() + " " +
			"ORDER BY created DESC "
		);

		this.viewCurrent = "direct_messages_conversation";
		this.viewAction = 3;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].direct_message_id;
		}
		this.viewInterface.showConversationDirectMessages(result);
	},

	//Calcula cuantos mensajes directos tiene una conversacion
	countDirectMessages: function countDirectMessages(screen_name)
	{
		var result1 = twitbin.dbtwitbin.query(
			"SELECT COUNT(*) as count FROM direct_messages " +
			"WHERE sender_screen_name = '" + twitbin.getLoggedUserName() + "' AND recipient_screen_name = '" + screen_name + "' "
		),
		result2 = twitbin.dbtwitbin.query(
			"SELECT COUNT(*) as count FROM direct_messages " +
			"WHERE recipient_screen_name = '" + twitbin.getLoggedUserName() + "' AND sender_screen_name = '" + screen_name + "' "
		);

		return result1[0].count + result2[0].count;
	},

	directMessagesSearchUser: function directMessagesSearchUser(search){
	    var result = twitbin.dbtwitbin.query(
            "SELECT owner_id, owner_screen_name FROM tweets " +
            "WHERE owner_screen_name LIKE '%" + search + "%' " +
            " AND owner_screen_name != '" + twitbin.getLoggedUserName() + "' " +
            " AND twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
            " GROUP BY owner_screen_name ORDER BY owner_screen_name ASC LIMIT 5 "
        );

        this.viewInterface.showDirectMessagesSearchUser(result);
	},

//--------------------------------------------
//	 LISTS
//--------------------------------------------

	//busca las listas para mostrar el tab de listas
	showAllList: function showAllList() {
		//report
		twitbin.reports.add('Session.lists');

		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM lists " +
			"WHERE twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"ORDER BY id ASC "
		);
		this.viewCurrent = "List";
		this.viewAction = 1;

		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].id;
		}

		this.viewInterface.showAllList(result);
	},

	//busca las para apendar al final, al hacer scroll (lists)
	appendAllList: function appendAllList() {
		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM lists " +
			"WHERE twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND id > " + this.viewLastItem + " " +
			"ORDER BY id ASC "
		);

		this.viewCurrent = "List";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].id;
		}
		this.viewInterface.showAllList(result);
	},

	//busca tweets de una lista particular listas para mostrar el tab de listas
	showTweetsOfLists: function showTweetsOfLists(idList)
	{
		if( this.viewCurrent != 'List' && this.viewCurrent != 'list_tweets' ){
			return false;
		}
		var result = twitbin.dbtwitbin.query(
			"SELECT tweets.* FROM tweet_lists, tweets " +
			"WHERE tweet_lists.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND tweet_lists.list_id = '" + idList + "' " +
			"AND tweets.type_tweet = 'TweetList' " +
			"AND tweets.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND tweet_lists.tweet_id = tweets.tweet_id " +
			"ORDER BY tweets.created DESC " +
			"LIMIT " + this.viewQuantityItems
		);

		this.viewCurrent = "list_tweets";
		this.viewAction = 1;

		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}

		this.viewInterface.showTweetsOfLists(idList, result);
	},

	//busca las para apendar al final, al hacer scroll (tweets)
	appendTweetsOfLists: function appendTweetsOfLists(idList)
	{
		var result,
		created = $("#" + this.viewLastItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			" SELECT tweets.* FROM tweet_lists, tweets " +
			" WHERE tweet_lists.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND tweet_lists.list_id = '" + idList + "' " +
				"AND tweets.type_tweet = 'TweetList' " +
				"AND tweets.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
				"AND tweet_lists.tweet_id = tweets.tweet_id " +
				"AND tweets.created < " + created +
			" ORDER BY tweets.created DESC " +
			" LIMIT " + this.viewQuantityItems
		);

		this.viewCurrent = "list_tweets";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}

		this.viewInterface.showTweetsOfLists(idList, result);
	},

	//busca las nuevos para apendar al inicio (tweets)
    appendNewTweetsOfLists: function appendNewTweetsOfLists(idList)
    {
        var result,
		created = $("#" + this.viewFirstItem + " .tweetCreated").html();

        result = twitbin.dbtwitbin.query(
            " SELECT tweets.* FROM tweet_lists, tweets " +
            " WHERE tweet_lists.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
                "AND tweet_lists.list_id = '" + idList + "' " +
                "AND tweets.type_tweet = 'TweetList' " +
                "AND tweets.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
                "AND tweet_lists.tweet_id = tweets.tweet_id " +
                "AND tweets.created > " + created +
            " ORDER BY tweets.created DESC "
        );

        this.viewCurrent = "list_tweets";
        this.viewAction = 4;
        if(typeof(result[0]) != "undefined"){
            this.viewFirstItem = result[0].tweet_id;
        }
        
        this.viewInterface.refreshDataTime();
        this.viewInterface.showTweetsOfLists(idList, result);
    },

//--------------------------------------------
//	 SEARCHES
//--------------------------------------------

	//busca las busquedas guardadas para mostrar el tab de searches
	showSearches: function showSearches()
	{
		//report
		twitbin.reports.add('Session.searches');

		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM searches " +
			"WHERE twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"ORDER BY query ASC "
		);
		this.viewCurrent = "searches";
		this.viewAction = 1;

		this.viewInterface.showSearches(result);
	},

	//busca tweets de una busqueda temporal hecha para mostrar el tab de searches
	showTempSearchTweets: function showTempSearchTweets()
	{
		var result = twitbin.dbtwitbin.query(
			"SELECT * FROM temp_tweets " +
			"WHERE twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND type_tweet = 'TweetSearch' " +
			"ORDER BY created DESC "
		);

		this.viewInterface.showTempTweetsOfSearches(result);
	},

	//busca tweets de una busqueda guardada para mostrar el tab de searches
	showTweetsOfSearches: function showTweetsOfSearches(searchID)
	{
		if( this.viewCurrent != 'searches' && this.viewCurrent != 'search_tweets'){
			return false;
		}
		var result = twitbin.dbtwitbin.query(
			"SELECT tweets.* FROM tweets_search, tweets " +
			"WHERE tweets_search.search_id = '" + searchID + "' " +
			"AND tweets.type_tweet = 'TweetSearch' " +
			"AND tweets.twitbin_user_screen_name = '" + twitbin.getLoggedUserName() + "' " +
			"AND tweets.tweet_id = tweets_search.tweet_id " +
			"GROUP BY tweet_id ORDER BY tweets.created DESC " +
			" LIMIT " + this.viewQuantityItems
		);

		this.viewCurrent = "search_tweets";
		this.viewAction = 1;
		if(typeof(result[0]) != "undefined"){
			this.viewFirstItem = result[0].tweet_id;
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}

		this.viewInterface.showTweetsOfSearches(searchID, result);
	},

	//busca las para apendar al final, al hacer scroll (tweets)
	appendTweetsOfSearches: function appendTweetsOfSearches(searchID)
	{
		var result,
		created = $("#" + this.viewLastItem + " .tweetCreated").html();

		result = twitbin.dbtwitbin.query(
			"SELECT tweets.* FROM tweets_search, tweets " +
			"WHERE tweets_search.search_id = '" + searchID + "' " +
			" AND tweets.type_tweet = 'TweetSearch' " +
			" AND tweets.tweet_id = tweets_search.tweet_id " +
			" AND tweets.created < " + created +
			" GROUP BY tweet_id ORDER BY tweets.created DESC " +
			" LIMIT " + this.viewQuantityItems
		);

		this.viewCurrent = "search_tweets";
		this.viewAction = 2;
		if(typeof(result[0]) != "undefined"){
			this.viewLastItem = result[(result.length - 1)].tweet_id;
		}

		this.viewInterface.showTweetsOfSearches(searchID, result);
	},

	//busca las nuevos para apendar al inicio (tweets)
    appendNewTweetsOfSearches: function appendNewTweetsOfSearches(searchID)
    {
        var result,
		created = $("#" + this.viewFirstItem + " .tweetCreated").html();

        result = twitbin.dbtwitbin.query(
            "SELECT tweets.* FROM tweets_search, tweets " +
            "WHERE tweets_search.search_id = '" + searchID + "' " +
            " AND tweets.type_tweet = 'TweetSearch' " +
            " AND tweets.tweet_id = tweets_search.tweet_id " +
            " AND tweets.created > " + created +
            " GROUP BY tweet_id ORDER BY tweets.created DESC "
        );

        this.viewCurrent = "search_tweets";
        this.viewAction = 4;
        if(typeof(result[0]) != "undefined"){
            this.viewFirstItem = result[0].tweet_id;
        }
        
        this.viewInterface.refreshDataTime();
        this.viewInterface.showTweetsOfSearches(searchID, result);
    },

	//agrega el boton de la busqueda recien guardada
	addNewSearch: function addNewSearch(search_id, query)
	{
		var obj,
		search = new Array();

		this.viewTweetsOfSearchCurrent = search_id;
		twitbin.taskScheduler.add({"f1":"twitbin.loadTweetsOfSavedSearch","p1":[twitbin.viewController.viewTweetsOfSearchCurrent]},1);

		obj = new function(){
			this.query = query;
			this.search_id = search_id;
		};

		search[0] = obj;
		this.viewInterface.addNewSearch(search);
	},

//--------------------------------------------
//	 MISC
//--------------------------------------------

	//llama a refrescar una vista en particular
	refresh: function refresh(sheduler, newItem){

		switch(sheduler){
            
			case 'TimeLine':
				if(this.viewCurrent == 'TimeLine'){
					this.appendNewTimeLineTweets();
					this.viewInterface.refreshDataTime();
				}
				else if ( newItem > 0) {
					this.viewInterface.setMenuNewItem( $("#navTimeLine") );
				}
			break;

			case 'Mentions':
				if(this.viewCurrent == 'Mentions'){
					this.appendNewMentionsTweets();
					this.viewInterface.refreshDataTime();
				}
				else if ( newItem > 0){
					this.viewInterface.setMenuNewItem( $("#navMention") );
				}
			break;

			case 'Favorite':
				if(this.viewCurrent == 'Favorite'){
					this.appendNewFavoriteTweets();
					this.viewInterface.refreshDataTime();
				}
			break;

			case 'DM':
				if(this.viewCurrent == 'direct_messages'){
					this.appendNewDirectMessages();
					this.viewInterface.refreshDataTime();
				}
				else if(this.viewCurrent == 'direct_messages_conversation'){
					this.appendNewConversationDirectMessages(this.viewScreenName);
					this.viewInterface.refreshDataTime();
				}
				else if(this.viewCurrent == 'direct_messages_sent'){
					this.appendNewDirectMessagesSent();
					this.viewInterface.refreshDataTime();
				}
				else if( newItem > 0){
					this.viewInterface.setMenuNewItem( $("#navDM") );
				}
			break;
			
			case 'ListTweets':
			    this.viewInterface.refreshDataTime();
			break;
		}
	},

	//abre el tab elegido
	openTab: function openTab(obj)
	{
		switch(obj.attr('id'))
		{
			case "navTimeLine":
				twitbin.viewController.showTimeLineTweets();
			break;

			case "navMention":
				twitbin.viewController.showMentionsTweets();
			break;

			case "navDM":
				twitbin.viewController.showDirectMessages();
			break;

			case "navFavorites":
				twitbin.viewController.showFavoriteTweets();
			break;

			case "navList":
				twitbin.viewController.showAllList();
			break;

			case "navSearch":
				twitbin.viewController.showSearches();
			break;
		}
		// Borrar los sheduler para no pasar el limite de pedidos a twitter
		twitbin.taskScheduler.remove({"f1":"twitbin.loadTweetsOfList","p1":[twitbin.viewController.viewTweetsOfListCurrent]});
		twitbin.taskScheduler.remove({"f1":"twitbin.loadTweetsOfSavedSearch","p1":[twitbin.viewController.viewTweetsOfSearchCurrent]});
	},

	//apenda los tweets (escondidos) a la vista correspondiente
	appendNewItem: function appendNewItem(divUpdate){
		$(divUpdate).prepend( $(this.viewInterface.boxNewItems).html() );
		this.viewFirstItem = this.viewFirstItemTemp;
		$(this.viewInterface.boxNewItems).html("");
		this.viewInterface.notificationArea('hide');
		this.viewInterface.ResetTwitbinButton();
		this.viewInterface.refreshDataTime();
	},


}
